body,html{height:100%}body{font-family:sans-serif;font-size:.9em;color:#444;padding:0;margin:0;background:#c13832}#app,.main{height:100%}.main{position:relative;background:#f6f4ec}.sidebar{position:fixed;background:#c13832;float:left;width:20vw;height:100%}.sidebar ul{list-style-type:none;margin:0;line-height:2em;padding:3em 1em 0}.sidebar li{border-radius:4px;margin-bottom:.5em;padding:0;height:100%}.sidebar li>a{display:block;width:100%;padding-right:1em;text-align:right;color:#f6f4ec;text-decoration:none}.sidebar li>a:after{content:"\A0\A0"}.sidebar li.active,.sidebar li:hover{background:#f6f4ec}.sidebar li.active a,.sidebar li:hover a{color:#c13832}.sidebar li a.unsynced:after{content:"*";margin-left:.1em}.sidebar hr{border:none;border-top:1px solid #f6f4ec}.content{background:#f6f4ec;padding:.5em 1vw 0 21vw}.content h1{font-size:1.3em;margin-top:0;border-bottom:1px dotted #aaa}.content a{color:#444;text-decoration:none;border-bottom:1px dashed #444}.collection-page h1 em{font-size:.6em;line-height:2.5em;font-weight:400;display:block;float:right}.server-info pre{background:#ddd;padding:1em;border-radius:4px}.server-info pre.error{background:#c13832;color:#f6f4ec}table.record-list{width:100%;border-collapse:collapse;font-size:.8em}table.record-list tbody tr,table.record-list thead tr{border-bottom:1px solid #ccc}table.record-list tbody tr{border-left:1px solid #ccc;border-right:1px solid #ccc}table.record-list td{padding:.3em .4em;max-width:300px;overflow:hidden;text-overflow:ellipsis}table.record-list tbody tr:nth-child(odd){background:#e5e3db}table.record-list tbody tr:nth-child(even){background:#f7f5fd}table.record-list tbody tr.unsynced{background:repeating-linear-gradient(45deg,#eee,#eee 10px,#ddd 10px,#ddd 20px)}table.record-list td.lastmod,table.record-list td.status{width:5pc;text-align:center}table.record-list td.actions{width:90pt;text-align:right;white-space:nowrap}p.actions a{font-size:.8em;margin-left:.5em}.notification{border-radius:8px;margin-bottom:1em}.notification .close{position:fixed;right:1.5vw;font-size:1.2em;color:#fff;border:0;padding-top:.2em}.notification h2{color:#fff;margin:0;font-size:1em;padding:.1em .4em .3em}.notification p{margin:.5em 0;padding:0 .5em;font-size:.8em}.notification li{color:#c13832;font-size:.8em}.notification-error{border:2px solid #c13832}.notification-error h2{background:#c13832}.notification-error p{color:#c13832}.notification-info{border:2px solid #368ca8}.notification-info h2{background:#368ca8}.notification-info p{color:#368ca8}a.link-button{text-decoration:none;border:none}.generic-form *{box-sizing:border-box}.generic-form{padding:0;font-size:.8em;color:#555}.generic-form fieldset{border:1px solid #aaa;border-radius:4px;margin-top:.5em}.generic-form fieldset legend{font-weight:700;margin-left:-.2em}.generic-form button{display:inline-block;color:#fff;background-color:#286090;border-color:#122b40;padding:2px 8px;font-size:14px;font-weight:400;line-height:1.5em;white-space:nowrap;vertical-align:middle;cursor:pointer;border:1px solid transparent;border-radius:4px}.generic-form input[type=text]{display:block;width:100%;height:34px;padding:3px 6px;font-size:14px;color:#555;border:1px solid #ccc;border-radius:4px;box-shadow:0 1px 1px rgba(0,0,0,.075) inset}.generic-form .errors{color:red}.generic-form .field{padding-top:1em}.generic-form .field label{display:block;font-weight:700}.generic-form .field select{display:block}.generic-form .array-item-add button,.generic-form .array-item-remove button{width:2pc;height:2pc}.generic-form .array-item-add{margin-bottom:0}.generic-form .array-item-remove{margin:.2em 0}.generic-form .field-array-of-string input[type=text]{width:calc(100% - 38px)}.generic-form .field-array-of-string .array-item-remove{float:right;width:30px;margin-top:-2.3em}